"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const path = require("path");
var sematicAnalyser = require('../Semantic Analyser/analyser');
var parser = require('../Parser/validator');
var generator = require('../Machines/CompilerUtils/machineGenerator');
const fs = require("fs");
class Build extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Build);
        const df = flags.dialogflow || false;
        let cwd = process.cwd();
        try {
            let atmtFile = path.join(cwd, 'bot.atmt.json');
            let atmtFileJson = JSON.parse(fs.readFileSync(atmtFile, 'utf-8'));
            let errors = parser(atmtFileJson)['errors'];
            if (errors.length > 0)
                throw new Error(JSON.stringify(errors, null, '\t'));
            let syntaxTree = sematicAnalyser(atmtFileJson);
            generator.create(syntaxTree, df);
            this.log('Done scaffolding from bot.atmt.json');
        }
        catch (err) {
            this.error(err);
        }
    }
}
Build.description = 'initial scaffolding from bot.atmt.json';
Build.examples = [
    `$ atmt build
`,
];
Build.flags = {
    dialogflow: command_1.flags.boolean({ char: 'd', description: 'use dialogflow' })
};
Build.args = [];
exports.default = Build;
